Alhambra API Reference
======================

.. currentmodule:: alhambra

The most important class, and the only one most people will need to use, is `TileSet`:

.. autosummary::
   :toctree: generated/

   TileSet


Other classes in the base module are:

.. autosummary::
   :toctree: generated/

   Tile
   TileList
   Glue
   GlueList
